diff --git a/modules/find/FindCBLAS.cmake b/modules/find/FindCBLAS.cmake
index 7d59311c99e248774d2e44094cb13e962338da76..0991c66b7f7ce6d88c6b433555e3c2ad73c2b24c 100644
--- a/modules/find/FindCBLAS.cmake
+++ b/modules/find/FindCBLAS.cmake
@@ -165,26 +165,27 @@ endmacro()
 
 # Look  for the cblas header files
 # ---------------------------------
-function(cblas_check_include)
-  if ( CBLAS_INCLUDE_DIRS )
-    return()
-  endif()
+macro(cblas_check_include)
 
-  # Try to find the cblas header in the given paths
-  # -------------------------------------------------
-  if (CBLAS_LIBRARIES MATCHES "libmkl")
-    set(CBLAS_hdrs_to_find "mkl.h")
-  else()
-    set(CBLAS_hdrs_to_find "cblas.h")
-  endif()
+  if ( NOT CBLAS_INCLUDE_DIRS )
+
+    # Try to find the cblas header in the given paths
+    # -------------------------------------------------
+    if (CBLAS_LIBRARIES MATCHES "libmkl")
+      set(CBLAS_hdrs_to_find "mkl.h")
+    else()
+      set(CBLAS_hdrs_to_find "cblas.h")
+    endif()
+
+    # call cmake macro to find the header path
+    # ----------------------------------------
+    morse_find_path(CBLAS
+      HEADERS  ${CBLAS_hdrs_to_find}
+      SUFFIXES "include" "include/cblas")
 
-  # call cmake macro to find the header path
-  # ----------------------------------------
-  morse_find_path(CBLAS
-    HEADERS  ${CBLAS_hdrs_to_find}
-    SUFFIXES "include" "include/cblas")
+  endif()
 
-endfunction()
+endmacro()
 
 # CBLAS depends on BLAS anyway, try to find it
 if(CBLAS_FIND_REQUIRED)
@@ -204,6 +205,7 @@ else()
 endif()
 
 # find CBLAS
+message(STATUS "CBLAS_BLAS ${CBLAS_BLAS}")
 if (CBLAS_BLAS)
 
   if (NOT CBLAS_STANDALONE)
@@ -212,6 +214,7 @@ if (CBLAS_BLAS)
     cblas_check_library("FALSE")
 
     # Blas lib includes cblas
+    message(STATUS "CBLAS_WORKS ${CBLAS_WORKS}")
     if(CBLAS_WORKS)
       if(NOT CBLAS_FIND_QUIETLY)
         message(STATUS "Looking for cblas: test with blas succeeded")
diff --git a/modules/find/FindLAPACKE.cmake b/modules/find/FindLAPACKE.cmake
index d526573c046a66e0afebf7ea713b92280f8a25ea..9e7320ace9b39563aaa9ae203733ba7adab1894e 100644
--- a/modules/find/FindLAPACKE.cmake
+++ b/modules/find/FindLAPACKE.cmake
@@ -172,26 +172,27 @@ endmacro()
 
 # Look  for the lapacke header files
 # ---------------------------------
-function(lapacke_check_include)
-  if ( LAPACKE_INCLUDE_DIRS )
-    return()
-  endif()
+macro(lapacke_check_include)
 
-  # Try to find the lapacke header in the given paths
-  # -------------------------------------------------
-  if (LAPACKE_LIBRARIES MATCHES "libmkl")
-    set(LAPACKE_hdrs_to_find "mkl.h")
-  else()
-    set(LAPACKE_hdrs_to_find "lapacke.h")
-  endif()
+  if ( NOT LAPACKE_INCLUDE_DIRS )
+
+    # Try to find the lapacke header in the given paths
+    # -------------------------------------------------
+    if (LAPACKE_LIBRARIES MATCHES "libmkl")
+      set(LAPACKE_hdrs_to_find "mkl.h")
+    else()
+      set(LAPACKE_hdrs_to_find "lapacke.h")
+    endif()
+
+    # call cmake macro to find the header path
+    # ----------------------------------------
+    morse_find_path(LAPACKE
+      HEADERS  ${LAPACKE_hdrs_to_find}
+      SUFFIXES "include" "include/lapacke" "include/mkl")
 
-  # call cmake macro to find the header path
-  # ----------------------------------------
-  morse_find_path(LAPACKE
-    HEADERS  ${LAPACKE_hdrs_to_find}
-    SUFFIXES "include" "include/lapacke" "include/mkl")
+  endif()
 
-endfunction()
+endmacro()
 
 # to check LAPACKE components
 set(LAPACKE_WITH_TMG OFF)